@@ -18,8 +18,7 @@
 #include <QMouseEvent>
 #include <QScrollBar>
 
-#include <klocale.h>
-#include <kdebug.h>
+#include <klocalizedstring.h>
 #include <math.h>
 
 #include "division.h"
@@ -312,7 +311,7 @@ void placeMapWidget::mouseMoveEvent(QMouseEvent *e)
 	}
 }
 
-void placeMapWidget::mouseReleaseEvent(QMouseEvent *e)
+void placeMapWidget::mouseReleaseEvent(QMouseEvent *)
 {
 	if ( p_mode == Zooming )
 	{
@@ -359,7 +358,7 @@ void placeMapWidget::wheelEvent(QWheelEvent *e)
 	}
 }
 
-void placeMapWidget::enterEvent(QEvent* e)
+void placeMapWidget::enterEvent(QEvent*)
 {
 	if (p_currentDivisionItem)
 	{
@@ -367,7 +366,7 @@ void placeMapWidget::enterEvent(QEvent* e)
 	}
 }
 
-void placeMapWidget::leaveEvent(QEvent* e)
+void placeMapWidget::leaveEvent(QEvent*)
 {
 	if (p_currentDivisionItem)
 	{
@@ -434,4 +433,4 @@ void placeMapWidget::updateActions()
 	emit setZoomActionChecked( p_mode == Zooming || p_mode == WantZoom );
 }
 
-#include "placemapwidget.moc"
+
